Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/core
diff options
context:
space:
mode:
authorThomas Steur <thomas.steur@googlemail.com>2014-12-04 06:33:32 +0300
committerThomas Steur <thomas.steur@googlemail.com>2014-12-04 06:33:32 +0300
commitccd58c88a7aa47a205c426feba7c2674708292a8 (patch)
treebfc5a5bc8425ce4c1bc9b60bd44665d9e861aa74 /core
parent3639b0eca7b4f7f56e9a2f67d3cfda48a466b625 (diff)
refs #6075 moved migration script to correct version
Diffstat (limited to 'core')
-rw-r--r--core/Updates/2.10.0-b4.php (renamed from core/Updates/2.9.1.php)8
-rw-r--r--core/Version.php2
2 files changed, 3 insertions, 7 deletions
diff --git a/core/Version.php b/core/Version.php
index 86a856f320..0585736f6d 100644
--- a/core/Version.php
+++ b/core/Version.php
@@ -20,5 +20,5 @@ final class Version
* The current Piwik version.
* @var string
*/
- const VERSION = '2.10.0-b3';
+ const VERSION = '2.10.0-b4';
}
diff --git a/core/Updates/2.9.1.php b/core/Updates/2.10.0-b4.php
index caaa92ee4b..88cbaf4df4 100644
--- a/core/Updates/2.9.1.php
+++ b/core/Updates/2.10.0-b4.php
@@ -12,15 +12,11 @@ namespace Piwik\Updates;
use Piwik\Updates;
/**
* Update for version 2.9.1.
*/
-class Updates_2_9_1 extends Updates
+class Updates_2_10_0_b4 extends Updates
{
- /**
- * Here you can define any action that should be performed during the update. For instance executing SQL statements,
- * renaming config entries, updating files, etc.
- */
static function update()
{
$pluginManager = \Piwik\Plugin\Manager::getInstance();
@@ -12,15 +12,11 @@ namespace Piwik\Updates;
use Piwik\Updates;
/**
- * Update for version 2.9.1.
+ * Update for version 2.10.0-b4.
*/